@@ -21,6 +21,10 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <glib/gstdio.h>
 #include <fcntl.h>
 #include <libecal/e-cal-util.h>
@@ -215,7 +219,7 @@ exchange_mapi_cal_util_fetch_attachments (ECalComponent *comp, GSList **attach_l
 		if (mapped_file && g_str_has_prefix (filename, uid)) {
 			ExchangeMAPIAttachment *attach_item;
 			ExchangeMAPIStream *stream; 
-			gchar *attach = g_mapped_file_get_contents (mapped_file);
+			guint8 *attach = (guint8 *) g_mapped_file_get_contents (mapped_file);
 			guint filelength = g_mapped_file_get_length (mapped_file);
 			const gchar *split_name = (filename + strlen (uid) + strlen ("-"));
 			uint32_t flag; 
@@ -1307,7 +1311,7 @@ exchange_mapi_cal_util_camel_helper (struct mapi_SPropValue_array *properties,
 	if (comp)
 		icalcomponent_add_component (icalcomp, 
 			icalcomponent_new_clone(e_cal_component_get_icalcomponent(comp)));
-	str = icalcomponent_as_ical_string (icalcomp);
+	str = icalcomponent_as_ical_string_r (icalcomp);
 	icalcomponent_free (icalcomp);
 	if (comp)
 		g_object_unref (comp);
